@@ -38,9 +38,9 @@ Enabling Signed Imports
 To enable signed imports, you need to create a SignedImportManager with the
 appropriate cryptographic keys and install it into the import machinery::
 
-    from signedimp import SignedImportManager, RSAKeyWithPSS
+    from signedimp import SignedImportManager, RSAKey
 
-    key = RSAKeyWithPSS(modulus,pub_exponent)
+    key = RSAKey(modulus,pub_exponent)
     mgr = SignedImportManager([key])
     mgr.install()
 
@@ -62,8 +62,8 @@ Currently signedimp uses RSA keys for its digital signatures, along with the
 "Probabilistic Signature Scheme" padding mechanism.  To generate a new key
 you will need PyCrypto installed, and to do the following::
 
-    from signedimp.crypto.rsa import RSAKeyWithPSS
-    key = RSAKeyWithPSS.generate()
+    from signedimp.crypto.rsa import RSAKey
+    key = RSAKey.generate()
     pubkey = key.get_public_key()
 
 Store this key somewhere safe, you'll need it to sign files.  The simplest way
@@ -75,7 +75,7 @@ is using the "save_to_file" method::
 To retreive the key in e.g. your build scripts, do something like this::
 
     with open("mykeyfile","rb") as f:
-        key = RSAKeyWithPSS.load_from_file(f,getpass())
+        key = RSAKey.load_from_file(f,getpass())
 
 You'll also need to embed the public key somewhere in your final executable
 so it's available for verifying imports.  The functions in signedimp.tools will
@@ -116,7 +116,7 @@ ASCII blobs.
 To create a manifest file you will need a key object that includes the private
 key data.  You can then use the functions in the "tools" submodule::
 
-    key = RSAKeyWithPSS(modulus,pub_exponent,priv_exponent)
+    key = RSAKey(modulus,pub_exponent,priv_exponent)
 
     signedimp.tools.sign_directory("some/dir/on/sys/path",key)
     signedimp.tools.sign_zipfile("some/zipfile/on/sys/path.zip",key)
@@ -141,9 +141,9 @@ signed executable. There are several options:
      script in the executable.
 
 Since the bootstrapping code can't perform any imports, everything (even the
-cryptographic primitives) is implemented in pure Python by default.  It is
+cryptographic primitives!) is implemented in pure Python by default.  It is
 thus rather slow.  If you're able to securely bundle e.g. hashlib or PyCrypto
-in the executable itself, import them before* installing the signed import
+in the executable itself, import them *before* installing the signed import
 manager so that it knows they are safe to use.
 
 Of course, the first thing the import manager does once installed is try to
@@ -160,7 +160,7 @@ and cxfreeze applications, and there are helper functions in "signedimp.tools"
 that will do it for you.
 
 I don't belive it's possible to sign a bbfreeze application without patching
-bbfreeze itsel.  Since bbfreeze always sets sys.path to the library.zip and
+bbfreeze itself.  Since bbfreeze always sets sys.path to the library.zip and
 the application dir, there is no way to bundle the bootstrapping code into
 the executable itself.
 
@@ -216,8 +216,8 @@ You have been warned.
 """
 
 __ver_major__ = 0
-__ver_minor__ = 1
-__ver_patch__ = 5
+__ver_minor__ = 2
+__ver_patch__ = 0
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 __version__ = "%d.%d.%d%s" % __ver_tuple__
