@@ -21,7 +21,7 @@ add the necessary bootstrapping code to your application.
 
 __all__ = ["HASHFILE_NAME","IntegrityCheckError",
            "IntegrityCheckFailed","IntegrityCheckMissing",
-           "SignedImportManager","SignedLoader","RSAKeyWithPSS",
+           "SignedImportManager","SignedLoader","RSAKey",
            "DefaultImporter"]
 
 
@@ -161,9 +161,9 @@ class _signedimp_util:
             _signedimp_util._sha1type = sha1
         return _signedimp_util._sha1type(data)
 
-    _RSAKeyWithPSS = None
+    _RSAKey = None
     @staticmethod
-    def RSAKeyWithPSS(modulus,pubexp,privexp=None):
+    def RSAKey(modulus,pubexp,privexp=None):
         """Pure-python implementation of RSA-PSS verification.
 
         This is horribly slow and probably broken, but it's the best we can do
@@ -171,10 +171,10 @@ class _signedimp_util:
         """
         #  The signedimp.tools.get_bootstrap_code() function will inline the
         #  raw code from signedimp.cryptobase.rsa
-        if not _signedimp_util._RSAKeyWithPSS:
-            from signedimp.cryptobase.rsa import RSAKeyWithPSS
-            _signedimp_util._RSAKeyWithPSS = RSAKeyWithPSS
-        return _signedimp_util._RSAKeyWithPSS(modulus,pubexp,privexp)
+        if not _signedimp_util._RSAKey:
+            from signedimp.cryptobase.rsa import RSAKey
+            _signedimp_util._RSAKey = RSAKey
+        return _signedimp_util._RSAKey(modulus,pubexp,privexp)
 
     @staticmethod
     def _b64unquad(quad):
@@ -253,7 +253,7 @@ class _signedimp_util:
             from signedimp.crypto import rsa
             _signedimp_util.md5 = md5.md5
             _signedimp_util.sha1 = sha1.sha1
-            _signedimp_util.RSAKeyWithPSS = rsa.RSAKeyWithPSS
+            _signedimp_util.RSAKey = rsa.RSAKey
         except (ImportError,IntegrityCheckMissing):
             # Try to use hashlib
             try:
@@ -314,6 +314,10 @@ class SignedHashDatabase(object):
             return _signedimp_util.md5(data).hexdigest() == hash
         raise ValueError("unknown hash type: %s" % (type,))
 
+    def _strip(self,s):
+        """Compatability wrapper for compiling string.strip() under pypy."""
+        return s.strip("\n").strip("\r").strip(" ")
+
     def parse_hash_data(self,hashdata):
         """Load hash data from the given string.
 
@@ -338,17 +342,18 @@ class SignedHashDatabase(object):
         #  Find all valid keys that have provided a signature.
         for ln in lines:
             offset += len(ln)+1
-            ln = ln.strip()
+            ln = self._strip(ln)
             if not ln:
                 break
             try:
-                fingerprint,signature = ln.split()
+                fingerprint,signature = ln.split(" ")
                 signature = _signedimp_util.b64decode(signature)
-            except ValueError, e:
+            except (ValueError,TypeError):
                 return
-            for k in self.valid_keys:
-                if k.fingerprint() == fingerprint:
-                    signatures.append((k,signature))
+            else:
+                for k in self.valid_keys:
+                    if k.fingerprint() == fingerprint:
+                        signatures.append((k,signature))
         #  If there weren't any usable signatures, we can't use this data.
         if not signatures:
             return
@@ -356,17 +361,20 @@ class SignedHashDatabase(object):
         signeddata = hashdata[offset:]
         for (k,sig) in signatures:
             if not k.verify(signeddata,sig):
-                err = "bad signature from " + fingerprint
+                err = "bad signature from " + k.fingerprint()
                 raise IntegrityCheckFailed(err)
         #  Next line is the hash type identifier
         try:
-            htyp = lines.next().strip()
+            htyp = self._strip(lines.next())
         except StopIteration:
             return
         #  Now we can load each hash line into the database
         for ln in lines:
             try:
-                typ,hval,name = ln.strip().split(None,2)
+                comps = self._strip(ln).split(" ")
+                typ = comps[0]
+                hval = comps[1]
+                name = " ".join(comps[2:])
             except ValueError:
                 continue
             try:
@@ -912,6 +920,8 @@ class DefaultImporter:
                 else:
                     # We're nowhere on sys.path
                     self.base_path = path
+        else:
+            self.base_path = base_path
 
     def _exists(self,*args):
         """Shortcut for checking if a file exists relative to my path."""
@@ -1085,9 +1095,9 @@ class DefaultImporter:
 
 
 
-def RSAKeyWithPSS(*args,**kwds):
-    """Wrapper to expose RSAKeyWithPSS at the top-level of the module."""
-    return _signedimp_util.RSAKeyWithPSS(*args,**kwds)
+def RSAKey(*args,**kwds):
+    """Wrapper to expose RSAKey at the top-level of the module."""
+    return _signedimp_util.RSAKey(*args,**kwds)
 
 
 #  Try to speed up initial imports by loading builtin or frozen utility mods.
@@ -1103,7 +1113,11 @@ class BuiltinOnlyImporter(BuiltinImporter):
     """
     @classmethod
     def find_module(self,fullname,path=None):
-        return self
+        loader = super(BuiltinOnlyImporter,self).find_module(fullname,path)
+        if loader is None:
+            raise ImportError(fullname + " is not builtin or frozen")
+        return loader
+
 
 sys.meta_path.insert(0,BuiltinOnlyImporter)
 _signedimp_util.recreate()
