@@ -14,6 +14,9 @@ import base64
 class TestBootstrap(unittest.TestCase):
 
     def test_b64_decode(self):
+        self.assertEquals(_signedimp_util.b64decode(base64.b64encode("")),"")
+        self.assertEquals(_signedimp_util.b64decode(base64.b64encode("\x00")),"\x00")
+        self.assertEquals(_signedimp_util.b64decode(base64.b64encode("\x00hello\x00")),"\x00hello\x00")
         for i in xrange(100):
             ln = random.randint(1,100)
             bs = os.urandom(ln)
