@@ -41,7 +41,7 @@ import subprocess
 import signedimp
 from signedimp.crypto.sha1 import sha1
 from signedimp.crypto.md5 import md5
-from signedimp.crypto.rsa import RSAKeyWithPSS
+from signedimp.crypto.rsa import RSAKey
 
 if sys.platform == "win32":
     from signedimp import winres
@@ -50,9 +50,9 @@ if sys.platform == "win32":
 def get_bootstrap_code(indent=""):
     """Get sourcecode you can use for inline bootstrapping of signed imports.
 
-    This function basically returns the source code for signedimp.bootstrap,
-    with some cryptographic primitives forcibly inlined as pure python, and
-    indented to the specified level.
+    This function returns code that, when executed, creates the signedimp
+    module and adds it to the local namespace as "signedimp". For most purposes 
+    executing this code should be equivalent to doing "import signedimp".
 
     You would use it to boostrap signed imports in the startup script of your
     application, e.g. build a script like the following and hand it off to
@@ -60,8 +60,8 @@ def get_bootstrap_code(indent=""):
 
        SCRIPT = '''
        %s
-       key = RSAKeyWithPSS(modulus,pub_exponent)
-       SignedImportManager([key]).install()
+       key = signedimp.RSAKey(modulus,pub_exponent)
+       signedimp.SignedImportManager([key]).install()
        actually_start_my_appliction()
        ''' % (signedimp.tools.get_bootstrap_code(),)
 
@@ -78,7 +78,23 @@ def get_bootstrap_code(indent=""):
                     yield newln
             else:
                 yield indent + ln
-    return "\n".join(_get_source_lines("signedimp.bootstrap",indent))
+    return """
+%(indent)ssignedimp = sys.modules.get("signedimp",None)
+%(indent)sif signedimp is None:
+%(indent)s    assert "imp" in sys.builtin_module_names
+%(indent)s    def _signedimp_init():
+%(indent)s        import imp
+%(indent)s        signedimp = imp.new_module("signedimp")
+%(bscode)s
+%(indent)s        lvars = locals()
+%(indent)s        for nm in __all__:
+%(indent)s            setattr(signedimp,nm,lvars[nm])
+%(indent)s        signedimp.__package__ == "signedimp"
+%(indent)s        signedimp.__path__ = []
+%(indent)s        signedimp._path_is_broken = True
+%(indent)s        return signedimp
+%(indent)s    signedimp = sys.modules["signedimp"] = _signedimp_init()
+""" % dict(indent=indent,bscode="\n".join(_get_source_lines("signedimp.bootstrap",indent+" "*8)))
 
 
 def sign_directory(path,key,hash="sha1",outfile=signedimp.HASHFILE_NAME):
@@ -234,13 +250,13 @@ def sign_py2exe_app(appdir,key=None,hash="sha1",check_modules=None):
     #  Since the public key will be embedded in the executables, it's OK to
     #  generate a throw-away key that's purely for signing this particular app.
     if key is None:
-        key = RSAKeyWithPSS.generate()
+        key = RSAKey.generate()
     pubkey = key.get_public_key()
     #  Build the bootstrapping code needed for each executable.
     #  We init the bootstrap objects inside a function so they get their own
     #  namespace; py2exe's own bootstrap code does a "del sys" which would
     #  play havoc with the import machinery.
-    bscodestr = get_bootstrap_code(indent="        ")
+    bscodestr = get_bootstrap_code()
     bscode =  """
 import sys
 
@@ -257,21 +273,7 @@ if %(do_check_modules)r and "signedimp" not in sys.modules:
 
 #  Get a reference to the signedimp module, possibly by creating
 #  it from raw code.
-signedimp = sys.modules.get("signedimp",None)
-if signedimp is None:
-    if %(do_check_modules)r:
-        assert "imp" in sys.builtin_module_names
-    def _signedimp_init():
-        %(bscodestr)s
-        signedimp = imp.new_module("signedimp")
-        lvars = locals()
-        for nm in __all__:
-            setattr(signedimp,nm,lvars[nm])
-        signedimp.__package__ == "signedimp"
-        signedimp.__path__ = []
-        signedimp._path_is_broken = True
-        return signedimp
-    signedimp = sys.modules["signedimp"] = _signedimp_init()
+%(bscodestr)s
 
 #  Add the specific key into the signed import machinery.
 k = signedimp.%(pubkey)r
@@ -349,10 +351,10 @@ def sign_py2app_bundle(appdir,key=None,hash="sha1",check_modules=None):
     #  Since the public key will be embedded in the executables, it's OK to
     #  generate a throw-away key that's purely for signing this particular app.
     if key is None:
-        key = RSAKeyWithPSS.generate()
+        key = RSAKey.generate()
     pubkey = key.get_public_key()
     #  Build the bootstrap code and put it at start of __boot__.py.
-    bscodestr = get_bootstrap_code(indent="        ")
+    bscodestr = get_bootstrap_code()
     bscode =  """
 import sys
 
@@ -369,21 +371,7 @@ if %(do_check_modules)r and "signedimp" not in sys.modules:
 
 #  Get a reference to the signedimp module, possibly by creating
 #  it from raw code.
-signedimp = sys.modules.get("signedimp",None)
-if signedimp is None:
-    if %(do_check_modules)r:
-        assert "imp" in sys.builtin_module_names
-    def _signedimp_init():
-        %(bscodestr)s
-        signedimp = imp.new_module("signedimp")
-        lvars = locals()
-        for nm in __all__:
-            setattr(signedimp,nm,lvars[nm])
-        signedimp.__package__ == "signedimp"
-        signedimp.__path__ = []
-        signedimp._path_is_broken = True
-        return signedimp
-    signedimp = sys.modules["signedimp"] = _signedimp_init()
+%(bscodestr)s
 
 #  Add the specific key into the signed import machinery.
 k = signedimp.%(pubkey)r
@@ -459,7 +447,7 @@ def sign_cxfreeze_app(appdir,key=None,hash="sha1",check_modules=None):
     #  Since the public key will be embedded in the executables, it's OK to
     #  generate a throw-away key that's purely for signing this particular app.
     if key is None:
-        key = RSAKeyWithPSS.generate()
+        key = RSAKey.generate()
     pubkey = key.get_public_key()
     #  Build the bootstrap code to be inserted into each executable.  Since
     #  it replaces the cx_Freeze__init__ script it needs to exec that once
@@ -659,9 +647,11 @@ def hash_files(path,files=None,hash="sha1",read=_read_file,os=os):
                             moddata.append(read(modpath))
                     moddata = "\x00".join(moddata)
                     modhashes[modname] = hash(moddata).hexdigest()
-    for nm,hash in modhashes.iteritems():
+    #  Concatenate the various hashes.  Put then in sorted order so
+    #  it's easy to locate a particular hash by hand.
+    for nm,hash in sorted(modhashes.items()):
         output.append("m %s %s" % (hash,nm))
-    for nm,hash in datahashes.iteritems():
+    for nm,hash in sorted(datahashes.iteritems()):
         output.append("d %s %s" % (hash,nm))
     return "\n".join(output)
 
